The hardware and bandwidth for this mirror is donated by METANET, the Webhosting and Full Service-Cloud Provider.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]metanet.ch.

Package {sksr}


Type: Package
Title: Labels for Danish SKS Codes
Version: 0.1.0
Description: The public available Danish SKS (Sundhedsvæsenets Klassifikationssystem) and SNOMED (Systematized Nomenclature of Medicine) codes with labels. The labels are useful to sort and make sense of microdata in closed computing environments. Current as of april 2026 (SNOMED) and june 2026 (SKS). SNOMED https://www.patobank.dk/snomed/ and SKS https://filer.sundhedsdata.dk/sks/data/skscomplete/.
License: MIT + file LICENSE
URL: https://github.com/LarsHernandez/sksr
BugReports: https://github.com/LarsHernandez/sksr/issues
Encoding: UTF-8
Suggests: rmarkdown
Imports: Rdpack
Depends: R (≥ 3.5.0)
RdMacros: Rdpack
LazyData: true
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-06-30 11:24:04 UTC; BP11MK
Author: Lars Boerty ORCID iD [aut, cre]
Maintainer: Lars Boerty <lars.borty@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-06 11:50:02 UTC

Data from the SKS dataset

Description

Data from the SKS dataset

Usage

data(SKS_labels)

Format

A data frame with ? rows and ? variables:

Prefix

Prefix kode kategori

Kode

SKS kode

Label

Label på dansk

Website

Examples

data(SKS_labels)



Data from the SKS dataset

Description

Data from the SKS dataset

Usage

data(SNOMED_labels)

Format

A data frame with ? rows and ? variables:

Kode

SNOMED kode

Label

Label på dansk

Website

Examples

data(SNOMED_labels)


These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.